##  Prerequisites
  * Activate the AI Agent API. To learn how to do this, see [Activating the API](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio1470a6a3f7d346bcaaecf1f0e8fcc04f__Activating-the-API).
  * Activate the AI agent extension to the meta model. If it’s not yet activated, you’re prompted to do this when activating the AI Agent API. This extension adds the needed entities to your workspace. To learn more, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
  * Prepare an API token. You can get an API token by creating a technical user in SAP LeanIX. Assign the admin or member role to the technical user. For additional information, see [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.").
